@@ -4,8 +4,6 @@ use base 'App::Netdisco::DB::ResultSet';
 use strict;
 use warnings;
 
-use Net::Domain 'hostfqdn';
-
 __PACKAGE__->load_components(qw/
   +App::Netdisco::DB::ExplicitLocking
 /);
@@ -25,7 +23,7 @@ C<retry_after> when devices will be retried once (disabled if 0/undef passed).
 
 sub skipped {
   my ($rs, $backend, $max_deferrals, $retry) = @_;
-  $backend ||= (hostfqdn || 'localhost');
+  $backend ||= 'fqdn-undefined';
   $max_deferrals ||= 10_000_000; # not really 'disabled'
   $retry ||= '100 years'; # not really 'disabled'
 
